#[repr(u8)]pub enum Apllcmre {
GENERATE_INTERRUPT = 0,
GENERATE_RESET = 1,
}Variants
GENERATE_INTERRUPT = 0
Clock monitor generates an interrupt when an error is detected
GENERATE_RESET = 1
Clock monitor generates a reset when an error is detected
Implementations