#[repr(u8)]pub enum Upllerr {
DISABLED_OR_NO_ERROR = 0,
ENABLED_AND_ERROR = 1,
}Variants
DISABLED_OR_NO_ERROR = 0
UPLL Clock Monitor is disabled or has not detected an error
ENABLED_AND_ERROR = 1
UPLL Clock Monitor is enabled and detected an error
Implementations